@@ -35,9 +35,9 @@
 #include <string.h>
 #include <cpl.h>
 
-#include "casu_utils.h"
+#include "catalogue/casu_utils.h"
 #include "casu_stats.h"
-#include "casu_fits.h"
+#include "catalogue/casu_fits.h"
 #include "casu_mods.h"
 
 /* Macro definitions */
@@ -173,7 +173,7 @@ extern int casu_imcombine(casu_fits **fset, casu_fits **fsetv, int nfits,
     char msg[SZBUF];
     float sumsky,sumsig,texp1,texp2,expfudge,skylevel,skynoise,oskynoise;
     float *dat,*work,**datas,**vars,*odata,*ovdata,oskylevel;
-    litestruct *ff,*fileptrs;
+    litestruct *ff,*fileptrs = NULL;
     cpl_image *im;
     cpl_propertylist *plist_p;
     cpl_binary **masks,*omask;
