@@ -34,8 +34,8 @@
 #include <math.h>
 #include <cpl.h>
 #include "casu_mods.h"
-#include "casu_utils.h"
-#include "casu_fits.h"
+#include "catalogue/casu_utils.h"
+#include "catalogue/casu_fits.h"
 #include "casu_stats.h"
 
 typedef struct {
