@@ -37,11 +37,11 @@
 
 #include "casu_sky.h"
 #include "casu_mask.h"
-#include "casu_fits.h"
+#include "catalogue/casu_fits.h"
 #include "casu_mods.h"
-#include "casu_utils.h"
+#include "catalogue/casu_utils.h"
 #include "casu_stats.h"
-#include "casu_wcsutils.h"
+#include "catalogue/casu_wcsutils.h"
 
 #define DATAMIN -1000.0
 #define DATAMAX 65535.0
@@ -119,7 +119,7 @@ extern int casu_pawsky_minus(casu_fits **infiles, casu_fits **invar,
     double *xin = NULL, *yin = NULL, *xout = NULL, *yout = NULL, *dx = NULL, *dy = NULL, ddx, ddy;
     int nx,ny,npts,ind,i,j,kind,ix,iy,jx,jy,*opm = NULL;
     int nx_mask = -1; /* return value for cpl_image_get_size_x on error */
-    int nfiles2,*confdata;
+    int nfiles2, *confdata = NULL;
     float **datas,*sky,*skyv,*zeros,val,sig,**vars;
     cpl_propertylist *plist;
     casu_fits **infiles2,**invar2;
@@ -254,7 +254,7 @@ extern int casu_pawsky_minus(casu_fits **infiles, casu_fits **invar,
         for (jy = 0; jy < ny; jy++) {
             for (jx = 0; jx < nx; jx++) {
                 ind = jy*nx + jx;
-                if (confdata[ind] == 0) {
+                if (confdata != NULL && confdata[ind] == 0) {
                     masks[i][ind] = 1;
                 } else if (objmaskfits != NULL) {
                     kind = (int)(yout[ind] + dy[i] - 0.5)*nx_mask + 
@@ -539,7 +539,7 @@ static void combine_mult(int nfiles, int stat, int npts, float **datas,
                          float **vars, unsigned char **masks, float *skyout,
                          float *skyvar) {
     int i,j,k,n;
-    float *buf,*bufv,*val,*valv;
+    float *buf,*bufv = NULL,*val,*valv = NULL;
 
     /* Get some memory */
 
