@@ -420,7 +420,7 @@ extern void imcore_overlp(ap_t *ap, float parm[IMNUM][NPAR], int *nbit,
             conv = 1;
             for (i = 0; i < *nbit; i++) {
                 if (parm[i][0] >= 0.0) {
-                    if (abs(bitx[i] - bitl[i]) > 3.0)
+                    if (fabs(bitx[i] - bitl[i]) > 3.0)
                         conv = 0;
                     bitl[i] = bitx[i];
                     bitx[i] = 0;
