@@ -50,6 +50,10 @@
 #define PV2_5  0.0
 
 /* Function prototypes */
+int hawki_aodata_nextn_correct(int nextn);
+
+cpl_error_code hawki_propagate_aoextensions(cpl_frameset * frameset,
+                                            const char * from, const char * to);
 
 extern const char *hawki_get_license(void);
 extern cpl_table *hawki_create_diffimg_stats(int nrows);
