@@ -115,6 +115,9 @@ static void hawki_image_copy_to_intersection_test(void)
         cpl_image_dump_window(from, 1, 1, 100, 100, dumpfrom);
         cpl_test_error(CPL_ERROR_NONE);
 
+        fclose(dumptarget);
+        fclose(dumpfrom);
+
         /* Compare a couple of values */
         val_target = cpl_image_get(target, 101, 101, &pix_reject);
         val_from = cpl_image_get(from, 1, 1, &pix_reject);
