@@ -38,32 +38,6 @@
                               Function prototypes
  -----------------------------------------------------------------------------*/
 
-/* TEMPORARY SUPPORT OF CPL 5.x */
-#ifndef CPL_SIZE_FORMAT
-#define CPL_SIZE_FORMAT "d"
-#define cpl_size int
-#endif
-
-#if defined CPL_VERSION_CODE && CPL_VERSION_CODE > CPL_VERSION(5, 92, 0)
-#define irplib_polynomial_add cpl_polynomial_add
-#define irplib_polynomial_subtract cpl_polynomial_subtract
-#define irplib_polynomial_multiply_scalar cpl_polynomial_multiply_scalar
-#else
-cpl_error_code irplib_polynomial_add(cpl_polynomial *,
-                                     const cpl_polynomial *,
-                                     const cpl_polynomial *);
-
-cpl_error_code irplib_polynomial_subtract(cpl_polynomial *,
-                                          const cpl_polynomial *,
-                                          const cpl_polynomial *);
-
-cpl_error_code irplib_polynomial_multiply_scalar(cpl_polynomial *,
-                                                 const cpl_polynomial *,
-                                                 double);
-#endif
-
-/* END TEMPORARY SUPPORT OF CPL 5.x */
-
 cpl_error_code irplib_polynomial_solve_1d_all(const cpl_polynomial *,
                                               cpl_vector *, cpl_size *);
 
