@@ -386,7 +386,8 @@ static int hawki_linearity_analyse(cpl_parameterlist *parlist,
     cpl_size nlab,mindeg,maxdeg,power,maxdeg_lin=1;
     cpl_parameter *p;
     int nfail,ncol,n,i,j,k,nx,ny,npix,k1,k2,ind,isrej,ndof,ntot;
-    cpl_frame *fr,*product_cube,*product_map,*product_tab;
+    cpl_frame *fr = NULL, *product_cube = NULL, *product_map = NULL;
+    cpl_frame *product_tab = NULL;
     cpl_image *darkim,*im;
     float data,sig;
     float reads[] = {9.8,8.9,8.2,8.3}; /* ADUs */
