@@ -279,7 +279,7 @@ static int hawki_step_photom_2mass(cpl_parameterlist *   parlist,
     
     /* Get some QC */
     qclists =  hawki_step_photom_2mass_qc(zpoint_table);
-    if(zpoint_table == NULL)
+    if(qclists == NULL)
     {
         cpl_msg_error(__func__,"Could not compute quality controls");
         cpl_frameset_delete(cat_2mass);
@@ -596,6 +596,7 @@ static cpl_array *   hawki_step_photom_2mass_ppm
     {
         cpl_msg_error(cpl_func,"Cannot sort 2MASS stars table");
         cpl_propertylist_delete(sort_prop);
+        cpl_matrix_delete(obj_pos);
         return NULL;
     }
 
@@ -937,17 +938,13 @@ static int hawki_step_photom_2mass_save
  cpl_frameset *       set)
 {
     cpl_propertylist *   protype;
-    cpl_frame *          ref_frame ;
     cpl_frameset *       combinedframes;
-    int                  nframes ;
     const char *         recipe_name = "hawki_step_photom_2mass" ;
 
     /* Initialise */
-    nframes = cpl_frameset_get_size(set) ;
 
     /* Get the reference frame */
     combinedframes = hawki_extract_frameset(set, HAWKI_CALPRO_COMBINED);
-    ref_frame = cpl_frameset_get_position(combinedframes, 0);
 
     /* Create the protype lists */
     protype = cpl_propertylist_new();
