@@ -29,23 +29,18 @@
 #include <math.h>
 #include <cpl.h>
 
-#include <hawki_dfs.h>
+#include <hawki_dfs_legacy.h>
 #include <hawki_load.h>
 #include <hawki_save.h>
-#include <hawki_pfits.h>
+#include <hawki_pfits_legacy.h>
 #include <hawki_image_stats.h>
-#include <hawki_utils.h>
+#include <hawki_utils_legacy.h>
 
 
 /*-----------------------------------------------------------------------------
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-extern "C"
-#endif
-int cpl_plugin_get_info(cpl_pluginlist * list);
-
 static int hawki_tec_filtchk_create(cpl_plugin *) ;
 static int hawki_tec_filtchk_exec(cpl_plugin *) ;
 static int hawki_tec_filtchk_destroy(cpl_plugin *) ;
@@ -69,7 +64,7 @@ static int hawki_tec_filtchk_save
  -----------------------------------------------------------------------------*/
 
 static char hawki_tec_filtchk_description[] =
-"hawki_tec_filtchk -- Check pairs of flats taken with different filters.\n"
+"(OBSOLETE) hawki_tec_filtchk -- Check pairs of flats taken with different filters.\n"
 "The files listed in the Set Of Frames (sof-file) must be tagged:\n"
 "raw-file.fits "HAWKI_TEC_FLAT_RAW"\n";
 
@@ -96,11 +91,11 @@ int cpl_plugin_get_info(cpl_pluginlist * list)
                     HAWKI_BINARY_VERSION,
                     CPL_PLUGIN_TYPE_RECIPE,
                     "hawki_tec_filtchk",
-                    "Filter checking recipe",
+                    "(OBSOLETE) Filter checking recipe",
                     hawki_tec_filtchk_description,
-                    "Cesar Enrique Garcia Dabo",
+                    "ESO Pipeline Group",
                     PACKAGE_BUGREPORT,  
-                    hawki_get_license(),
+                    hawki_get_license_legacy(),
                     hawki_tec_filtchk_create,
                     hawki_tec_filtchk_exec,
                     hawki_tec_filtchk_destroy) ;
@@ -204,7 +199,7 @@ static int hawki_tec_filtchk(
     char                protype[1024];
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (hawki_dfs_set_groups(framelist)) 
+    if (hawki_dfs_set_groups_legacy(framelist)) 
     {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         return -1;
